@@ -12,7 +12,7 @@ use constant {
 use List::Util qw(min max);
 
 BEGIN {
-    our $VERSION = 1.03;
+    our $VERSION = 1.04;
 }
 
 sub _perl_logo {
@@ -211,17 +211,17 @@ sub splash {
             {
                 'coordinates' => [(400 * $hf) + $X, (80 * $vf) + $Y, (20 * $hf) + $X, (800 * $vf) + $Y, (1600 * $hf) + $X, (1078 * $vf) + $Y, (1900 * $hf) + $X, (5 * $vf) + $Y],
                 'filled'      => TRUE,
-#                'gradient'    => {
-#                    'colors' => {
-#                        'red'   => [0,0],
-#                        'green' => [0,0],
-#                        'blue'  => [64,255],
-#                    },
-#                }
+                'gradient'    => {
+                    'colors' => {
+                        'red'   => [0,0],
+                        'green' => [0,0],
+                        'blue'  => [16,255],
+                    },
+                }
             }
         );
 
-        $self->set_color({ 'red' => 255, 'green' => 0, 'blue' => 0, 'alpha' => 128 });
+        $self->set_color({ 'red' => 255, 'green' => 0, 'blue' => 0, 'alpha' => 100 });
         $self->alpha_mode();
         $self->rbox(
             {
@@ -230,7 +230,16 @@ sub splash {
                 'width'  => 1660 * $hf,
                 'height' => 800  * $vf,
                 'radius' => 15   * min($hf, $vf),
-                'filled' => TRUE
+                'filled' => TRUE,
+                'gradient' => {
+                    'direction' => 'vertical',
+                    'colors' => {
+                        'red'   => [32,200],
+                        'green' => [0,0],
+                        'blue'  => [0,0],
+                        'alpha' => [96,255],
+                    },
+                },
             }
         );
 
@@ -275,7 +284,7 @@ sub splash {
                 'y'             => (202 * $vf) + $Y,
                 'radius'        => 52 * $vf,
                 'start_degrees' => 340,
-                'end_degrees'   => 270,
+                'end_degrees'   => 269,
                 'granularity'   => 0.05
             }
         );
@@ -335,7 +344,7 @@ sub splash {
                 'y'             => (200 * $vf) + $Y,
                 'radius'        => 52 * $vf,
                 'start_degrees' => 340,
-                'end_degrees'   => 270,
+                'end_degrees'   => 269,
                 'granularity'   => 0.05
             }
         );
@@ -417,19 +426,16 @@ sub splash {
                 'y'        => (200 * $vf) + $Y,
                 'width'    => (1230 * $hf),
                 'height'   => (150 * $vf),
-                'radius'   => 20 * $vf,
+                'radius'   => 10 * $vf,
                 'filled'   => TRUE,
                 'gradient' => {
-                    'start' => {
-                        'red'   => 0,
-                        'green' => 255,
-                        'blue'  => 0
+                    'direction' => 'vertical',
+                    'colors' => {
+                        'red'   => [0,255],
+                        'green' => [255,255],
+                        'blue'  => [0,0],
+                        'alpha' => [255,255],
                     },
-                    'end' => {
-                        'red'   => 255,
-                        'green' => 255,
-                        'blue'  => 0
-                    }
                 }
             }
         );
@@ -442,9 +448,9 @@ sub splash {
                         'x'            => (510 * $hf) + $X,
                         'y'            => (351 * $vf) + $Y,
                         'height'       => 110 * $vf,
-                        'wscale'       => 1.5,
+                        'wscale'       => 1.3,
                         'color'        => '0101FFFF',
-                        'text'         => 'Accelerated',
+                        'text'         => ($self->{'ACCELERATED'} == 2) ? 'GPU Accelerated' : 'C Accelerated',
                         'bounding_box' => TRUE,
                         'center'       => 0,
                         'antialias'    => ($self->{'BITS'} >= 24) ? TRUE : FALSE
